<?php

include "common/admin.php";

class Meow_Contact_Form_Admin extends MeowApps_Admin {

	public function __construct( $prefix, $mainfile, $domain ) {
		parent::__construct( $prefix, $mainfile, $domain );
		add_action( 'admin_menu', array( $this, 'app_menu' ) );
	}

	function common_url( $file ) {
		return trailingslashit( plugin_dir_url( __FILE__ ) ) . 'common/' . $file;
	}

	function app_menu() {

		// SUBMENU > Settings
		add_submenu_page( 'meowapps-main-menu', 'Contact Form', 'Contact Form', 'manage_options',
			'mcfb_settings-menu', array( $this, 'admin_settings' ) );

			// SUBMENU > Google Captcha
			add_settings_section( 'mcfb_captcha_settings', null, null, 'mcfb_captcha_settings-menu' );
			add_settings_field( 'mcfb_captcha_key', "Public Key",
				array( $this, 'admin_captcha_key_callback' ),'mcfb_captcha_settings-menu', 'mcfb_captcha_settings' );
			add_settings_field( 'mcfb_captcha_secret_key', "Secret Key",
				array( $this, 'admin_captcha_secret_key_callback' ),'mcfb_captcha_settings-menu', 'mcfb_captcha_settings' );

			// SUBMENU > Settings
			add_settings_section( 'mcfb_settings', null, null, 'mcfb_settings-menu' );
			add_settings_field( 'mcfb_redirect_url', "Redirect URL",
				array( $this, 'admin_redirect_url_callback' ),'mcfb_settings-menu', 'mcfb_settings' );
			add_settings_field( 'mcfb_phone_field', "Phone Field",
				array( $this, 'admin_phone_field_callback' ),'mcfb_settings-menu', 'mcfb_settings' );


		// SETTINGS
		register_setting( 'mcfb_captcha_settings', 'mcfb_captcha_key' );
		register_setting( 'mcfb_captcha_settings', 'mcfb_captcha_secret_key' );
		register_setting( 'mcfb_settings', 'mcfb_redirect_url' );
		register_setting( 'mcfb_settings', 'mcfb_phone_field' );
	}

	function admin_settings() {
		?>
		<div class="wrap">
			<?php
				echo $this->display_title( "Contact Form Block" );
			?>
			<div class="meow-section meow-group">
				<div class="meow-box meow-col meow-span_2_of_2">
					<h3>How to use</h3>
					<div class="inside">
						<?php echo _e( "The Contact Form Block has support for the latest version of reCAPTCHA (v3) to avoid spam and abuse. To enable it, please <a target='_blank' href='https://www.google.com/recaptcha/admin/create'>create your keys with Google</a> and simply paste then below. That's all :) To know more about it, <a target='_blank' href='https://www.google.com/recaptcha/intro/v3.html'>click here</a>. The official website of the Contact Form Block can be found <a target='_blank' href='https://meowapps.com/plugin/contact-form-block/'>here</a>.", 'contact-form-block' ); ?>
					</div>
				</div>
			</div>

			<div class="meow-section meow-group">

				<div class="meow-col meow-span_1_of_2">

					<div class="meow-box">
						<h3>Google Captcha v3</h3>
						<div class="inside">
							<form method="post" action="options.php">
							<?php settings_fields( 'mcfb_captcha_settings' ); ?>
							<?php do_settings_sections( 'mcfb_captcha_settings-menu' ); ?>
							<?php submit_button(); ?>
							</form>
						</div>
					</div>

					<div class="meow-box">
						<h3>Settings</h3>
						<div class="inside">
							<form method="post" action="options.php">
							<?php settings_fields( 'mcfb_settings' ); ?>
							<?php do_settings_sections( 'mcfb_settings-menu' ); ?>
							<?php submit_button(); ?>
							</form>
						</div>
					</div>

				</div>

			</div>
		</div>
		<?php
	}

	/*
		OPTIONS CALLBACKS
	*/

	function admin_captcha_key_callback( $args ) {
		$value = get_option( 'mcfb_captcha_key', '' );
		echo '<input type="text" id="mcfb_captcha_key" name="mcfb_captcha_key" value="' . $value . '" />';
	}

	function admin_captcha_secret_key_callback( $args ) {
		$value = get_option( 'mcfb_captcha_secret_key', '' );
		echo '<input type="text" id="mcfb_captcha_secret_key" name="mcfb_captcha_secret_key" value="' . $value . '" />';
	}

	function admin_redirect_url_callback( $args ) {
		$value = get_option( 'mcfb_redirect_url', '' );
		$html = '<input type="text" id="mcfb_redirect_url" name="mcfb_redirect_url" value="' . $value . '" />';
		$html .= '<br /><span class="description">The visitor will be redirect to this URL after the message was sent. If empty, the success message will be shown on the form itself.</label>';
		echo $html;
	}

	function admin_phone_field_callback( $args ) {
		$html = '<input type="checkbox" id="mcfb_phone_field" name="mcfb_phone_field" value="1" ' .
			checked( 1, get_option( 'mcfb_phone_field', false ), false ) . '/>';
		$html .= '<label>' . __( 'Enabled', 'contact-form-block' ) . '</label>';
		echo $html;
	}

}

?>
